==> jc-1.4.0.tar.gz: ppg/code/InitCode.h <==
// public class ppg.code.InitCode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ff40332975ef3bc9 ppg_code_Code
// @dep_class dc70c1553a4fdfdc ppg_code_InitCode

// header file dependencies
// @dep_header ppg_code_Code

#include "ppg/code/Code.h"

#ifndef _JC_ppg_code_InitCode_H_
#define _JC_ppg_code_InitCode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_code_InitCode$sub_refs	_jc_ppg_code_InitCode$sub_refs;
typedef struct _jc_ppg_code_InitCode$sub_nonrefs	_jc_ppg_code_InitCode$sub_nonrefs;
typedef struct _jc_ppg_code_InitCode$refs	_jc_ppg_code_InitCode$refs;
typedef struct _jc_ppg_code_InitCode$nonrefs	_jc_ppg_code_InitCode$nonrefs;
typedef struct _jc_ppg_code_InitCode$object	_jc_ppg_code_InitCode$object;

typedef const struct _jc_ppg_code_InitCode$vmethods	_jc_ppg_code_InitCode$vmethods;
typedef const struct _jc_ppg_code_InitCode$vtable	_jc_ppg_code_InitCode$vtable;
typedef const struct _jc_ppg_code_InitCode$vtype	_jc_ppg_code_InitCode$vtype;

// Constructors
extern void _jc_ppg_code_InitCode$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_code_InitCode$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_code_InitCode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_code_InitCode$object *);
extern struct _jc_java_lang_String$object *_jc_ppg_code_InitCode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_code_InitCode$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_code_InitCode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_code_InitCode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_code_InitCode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_code_InitCode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_code_InitCode$object *);
};

// Vtable
struct _jc_ppg_code_InitCode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_code_Code$vmethods	ppg_code_Code;
	_jc_ppg_code_InitCode$vmethods	ppg_code_InitCode;
};

// Vtype
struct _jc_ppg_code_InitCode$vtype {
	_jc_type			type;
	_jc_ppg_code_InitCode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_code_InitCode$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_code_InitCode$refs {
    _jc_ppg_code_InitCode$sub_refs	ppg_code_InitCode;
    _jc_ppg_code_Code$sub_refs	ppg_code_Code;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_code_InitCode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_code_InitCode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_code_Code$sub_nonrefs	ppg_code_Code;
    _jc_ppg_code_InitCode$sub_nonrefs	ppg_code_InitCode;
};

// Object instance structure
struct _jc_ppg_code_InitCode$object {
	_jc_ppg_code_InitCode$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_code_InitCode$vtype	*vtype;
	_jc_ppg_code_InitCode$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_code_InitCode$vtype _jc_ppg_code_InitCode$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_code_InitCode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_code_InitCode$class_object;

#endif	/* _JC_ppg_code_InitCode_H_ */

==> jc-1.4.6.tar.gz: ppg/code/InitCode.h <==
// public class ppg.code.InitCode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ff40332975ef3bc9 ppg_code_Code
// @dep_class dc70c1553a4fdfdc ppg_code_InitCode

// header file dependencies
// @dep_header ppg_code_Code

#include "ppg/code/Code.h"

#ifndef _JC_ppg_code_InitCode_H_
#define _JC_ppg_code_InitCode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_code_InitCode$sub_refs	_jc_ppg_code_InitCode$sub_refs;
typedef struct _jc_ppg_code_InitCode$sub_nonrefs	_jc_ppg_code_InitCode$sub_nonrefs;
typedef struct _jc_ppg_code_InitCode$refs	_jc_ppg_code_InitCode$refs;
typedef struct _jc_ppg_code_InitCode$nonrefs	_jc_ppg_code_InitCode$nonrefs;
typedef struct _jc_ppg_code_InitCode$object	_jc_ppg_code_InitCode$object;

typedef const struct _jc_ppg_code_InitCode$vmethods	_jc_ppg_code_InitCode$vmethods;
typedef const struct _jc_ppg_code_InitCode$vtable	_jc_ppg_code_InitCode$vtable;
typedef const struct _jc_ppg_code_InitCode$vtype	_jc_ppg_code_InitCode$vtype;

// Constructors
extern void _jc_ppg_code_InitCode$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_code_InitCode$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_code_InitCode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_code_InitCode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_ppg_code_InitCode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_code_InitCode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_code_InitCode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_code_InitCode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_code_InitCode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_code_InitCode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_code_InitCode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_code_InitCode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_code_Code$vmethods	ppg_code_Code;
	_jc_ppg_code_InitCode$vmethods	ppg_code_InitCode;
};

// Vtype
struct _jc_ppg_code_InitCode$vtype {
	_jc_type			type;
	_jc_ppg_code_InitCode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_code_InitCode$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_code_InitCode$refs {
    _jc_ppg_code_InitCode$sub_refs	ppg_code_InitCode;
    _jc_ppg_code_Code$sub_refs	ppg_code_Code;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_code_InitCode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_code_InitCode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_code_Code$sub_nonrefs	ppg_code_Code;
    _jc_ppg_code_InitCode$sub_nonrefs	ppg_code_InitCode;
};

// Object instance structure
struct _jc_ppg_code_InitCode$object {
	_jc_ppg_code_InitCode$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_code_InitCode$vtype	*vtype;
	_jc_ppg_code_InitCode$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_code_InitCode$vtype _jc_ppg_code_InitCode$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_code_InitCode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_code_InitCode$class_object;

#endif	/* _JC_ppg_code_InitCode_H_ */
